--- otp_src_R14B01/lib/stdlib/src/slave.erl	2010-12-07 10:07:22.000000000 -0500
+++ /home/kmontuori/projects/opsrv/apps/opsrv/src/opsrv_slave.erl	2011-07-08 09:46:55.227348000 -0400
@@ -16,7 +16,7 @@
 %% 
 %% %CopyrightEnd%
 %%
--module(slave).
+-module(opsrv_slave).
 
 %% If the macro DEBUG is defined during compilation, 
 %% debug printouts are done through erlang:display/1.
@@ -29,9 +29,9 @@
 
 -export([pseudo/1,
 	 pseudo/2,
-	 start/1, start/2, start/3,
+	 start/1, start/2, start/3, start/4,
 	 start/5,
-	 start_link/1, start_link/2, start_link/3,
+	 start_link/1, start_link/2, start_link/3, start_link/4,
 	 stop/1,
 	 relay/1]).
 
@@ -129,7 +129,11 @@
     start(Host, Name, []).
 
 start(Host, Name, Args) ->
-    start(Host, Name, Args, no_link).
+    start(Host, Name, Args, []).
+
+start(Host, Name, Args, RshArgs) ->
+    start(Host, Name, Args, no_link, {rsh_args, RshArgs}).
+    
 
 start_link(Host) ->
     L = atom_to_list(node()),
@@ -140,13 +144,19 @@
     start_link(Host, Name, []).
 
 start_link(Host, Name, Args) ->
-    start(Host, Name, Args, self()).
+    start(Host, Name, Args, []).
+
+start_link(Host, Name, Args, RshArgs) ->
+    start(Host, Name, Args, self(), {rsh_args, RshArgs}).
 
-start(Host0, Name, Args, LinkTo) ->
+start(Host0, Name, Args, LinkTo, {rsh_args, RshArgs}) ->
     Prog = lib:progname(),
-    start(Host0, Name, Args, LinkTo, Prog).
+    start(Host0, Name, Args, LinkTo, Prog, RshArgs);
 
 start(Host0, Name, Args, LinkTo, Prog) ->
+    start(Host0, Name, Args, LinkTo, Prog, []).
+
+start(Host0, Name, Args, LinkTo, Prog, RshArgs) ->
     Host =
 	case net_kernel:longnames() of
 	    true -> dns(Host0);
@@ -156,7 +166,7 @@
     Node = list_to_atom(lists:concat([Name, "@", Host])),
     case net_adm:ping(Node) of
 	pang ->
-	    start_it(Host, Name, Node, Args, LinkTo, Prog);
+	    start_it(Host, Name, Node, Args, LinkTo, Prog, RshArgs);
 	pong -> 
 	    {error, {already_running, Node}}
     end.
@@ -170,18 +180,20 @@
 
 %% Starts a new slave node.
 
-start_it(Host, Name, Node, Args, LinkTo, Prog) ->
+start_it(Host, Name, Node, Args, LinkTo, Prog, RshArgs) ->
     spawn(?MODULE, wait_for_slave, [self(), Host, Name, Node, Args, LinkTo,
-				    Prog]),
+				    Prog, RshArgs]),
     receive
 	{result, Result} -> Result
     end.
 
 %% Waits for the slave to start.
-
 wait_for_slave(Parent, Host, Name, Node, Args, LinkTo, Prog) ->
+    wait_for_slave(Parent, Host, Name, Node, Args, LinkTo, Prog, []).
+
+wait_for_slave(Parent, Host, Name, Node, Args, LinkTo, Prog, RshArgs) ->
     Waiter = register_unique_name(0),
-    case mk_cmd(Host, Name, Args, Waiter, Prog) of
+    case mk_cmd(Host, Name, Args, Waiter, Prog, RshArgs) of
 	{ok, Cmd} ->
 %%	    io:format("Command: ~s~n", [Cmd]),
 	    open_port({spawn, Cmd}, [stream]),
@@ -243,21 +255,22 @@
 %% If the node should run on the local host, there is
 %% no need to use rsh.
 
-mk_cmd(Host, Name, Args, Waiter, Prog) ->
+mk_cmd(Host, Name, Args, Waiter, Prog, RshArgs) ->
     BasicCmd = lists:concat([Prog,
 			     " -detached -noinput -master ", node(),
 			     " ", long_or_short(), Name, "@", Host,
 			     " -s slave slave_start ", node(),
 			     " ", Waiter,
 			     " ", Args]),
-	   
+
     case after_char($@, atom_to_list(node())) of
 	Host ->
 	    {ok, BasicCmd};
 	_ ->
 	    case rsh() of
 		{ok, Rsh} ->
-		    {ok, lists:concat([Rsh, " ", Host, " ", BasicCmd])};
+		    {ok, lists:concat([Rsh, " ", RshArgs, " ",
+                                       Host, " ", BasicCmd])};
 		Other ->
 		    Other
 	    end
